pub enum TrackValueKind {
Real,
Vector2,
Vector3,
Vector4,
UnitQuaternionEuler,
UnitQuaternion,
}Expand description
The kind of track output value, the animation system works only with numeric properties and the number of variants is small.
Variants
Real
A real number. Requires only 1 parametric curve.
Vector2
A 2-dimensional vector of real values. Requires 2 parametric curves, where X = 0 and Y = 1.
Vector3
A 3-dimensional vector of real values. Requires 3 parametric curves, where X = 0, Y = 1, Z = 2.
Vector4
A 4-dimensional vector of real values. Requires 4 parametric curves, where X = 0, Y = 1, Z = 2, W = 3.
UnitQuaternionEuler
A quaternion that represents some rotation. Requires 3 parametric curves, where XAngle = 0, YAngle = 1,
ZAngle = 2. The order of rotations is XYZ. This triple of curves forms Euler angles which are interpolated
and then converted to a quaternion.
UnitQuaternion
A quaternion that represents some rotation. Requires 4 parametric curves for each component. The order is XYZW.
Implementations
Sourceimpl TrackValueKind
impl TrackValueKind
Sourcepub fn components_count(self) -> usize
pub fn components_count(self) -> usize
Returns count of elementary components of a value kind. For example: Vector3 consists of 3 components where each component has its own parametric curve.