pub struct FixedEventQueue<T: EntityId> { /* private fields */ }Expand description
A simple event queue with fixed capacity. It is used to store a fixed amount of events and discard any events when the queue is full.
Implementations