pub struct BlendAnimations<T: EntityId> {
pub base: BasePoseNode<T>,
pub pose_sources: Vec<BlendPose<T>>,
pub output_pose: RefCell<AnimationPose<T>>,
}Expand description
Animation blend node. It takes multiple input poses and mixes them together into single pose with specified weights. Could be used to mix hit and run animations for example - once your character got hit, you set some significant weight for hit animation (0.8 for example) and lower weight for run animation (0.2) and it will look like your character got wounded while it still running (probably you should decrease speed here too). Weights can be parametrized, which means that you can dynamically change them in runtime. In our example we can decrease weight of hit animation over time and increase weight of run animation, so character will recover from his wounds.
Fields
base: BasePoseNode<T>Base node.
pose_sources: Vec<BlendPose<T>>A list of pose sources. See BlendPose docs for more info.
output_pose: RefCell<AnimationPose<T>>Output pose of the node, contains final result of blending all input poses.
Implementations
Sourceimpl<T: EntityId> BlendAnimations<T>
impl<T: EntityId> BlendAnimations<T>