AnimationPoseSource

Trait AnimationPoseSource 

pub trait AnimationPoseSource<T: EntityId> {
    // Required methods
    fn eval_pose(
        &self,
        nodes: &Pool<PoseNode<T>>,
        params: &ParameterContainer,
        animations: &AnimationContainer<T>,
        dt: f32,
    ) -> Ref<'_, AnimationPose<T>>;
    fn pose(&self) -> Ref<'_, AnimationPose<T>>;
    fn collect_animation_events(
        &self,
        nodes: &Pool<PoseNode<T>>,
        params: &ParameterContainer,
        animations: &AnimationContainer<T>,
        strategy: AnimationEventCollectionStrategy,
    ) -> Vec<(Handle<Animation<T>>, AnimationEvent)>;
}
A trait that responsible for animation pose evaluation.

Required Methods

fn eval_pose( &self, nodes: &Pool<PoseNode<T>>, params: &ParameterContainer, animations: &AnimationContainer<T>, dt: f32, ) -> Ref<'_, AnimationPose<T>>

Evaluates animation pose and returns a reference to it.

fn pose(&self) -> Ref<'_, AnimationPose<T>>

Returns a reference to inner pose of a node.

fn collect_animation_events( &self, nodes: &Pool<PoseNode<T>>, params: &ParameterContainer, animations: &AnimationContainer<T>, strategy: AnimationEventCollectionStrategy, ) -> Vec<(Handle<Animation<T>>, AnimationEvent)>

Collects animation events from internals.

Implementors