State

Struct State 

pub struct State<T: EntityId> {
    pub position: Vector2<f32>,
    pub name: String,
    pub on_enter_actions: Vec<StateActionWrapper<T>>,
    pub on_leave_actions: Vec<StateActionWrapper<T>>,
    pub root: Handle<PoseNode<T>>,
}
State is a final “container” for animation pose. It has backing pose node which provides a set of values. States can be connected with each other using transitions, states with transitions form a state graph.

Fields

position: Vector2<f32>

Position of state on the canvas. It is editor-specific data.

name: String

Name of the state.

on_enter_actions: Vec<StateActionWrapper<T>>

A set of actions that will be executed when entering the state.

on_leave_actions: Vec<StateActionWrapper<T>>

A set of actions that will be executed when leaving the state.

root: Handle<PoseNode<T>>

Root node of the state that provides the state with animation data.

Implementations

Source

impl<T: EntityId> State<T>

pub const POSITION: &'static str = "position"

pub const NAME: &'static str = "name"

pub const ON_ENTER_ACTIONS: &'static str = "on_enter_actions"

pub const ON_LEAVE_ACTIONS: &'static str = "on_leave_actions"

pub const ROOT: &'static str = "root"

Source

impl<T: EntityId> State<T>

pub fn new(name: &str, root: Handle<PoseNode<T>>) -> Self

Creates new instance of state with a given pose.

pub fn pose<'a>( &self, nodes: &'a Pool<PoseNode<T>>, ) -> Result<Ref<'a, AnimationPose<T>>, PoolError>

Returns a final pose of the state.

pub fn collect_animations( &self, nodes: &Pool<PoseNode<T>>, animations: &mut FxHashSet<Handle<Animation<T>>>, )

Collects all animation handles used by this state.