pub struct ImageParameters {
pub width: u32,
pub height: u32,
pub frame_width: u32,
pub frame_height: u32,
pub first_frame: u32,
pub last_frame: u32,
pub column_major: bool,
}Expand description
Sprite sheet source image parameters defines how to interpret an image. It defines size of each frame, total size of an image, frame range to use, etc.
Fields
width: u32Width of an image in pixels.
height: u32Height of an image in pixels.
frame_width: u32Width of every frame in an image.
frame_height: u32Height of every frame in an image.
first_frame: u32Index of a first frame at which a produced animation should start.
last_frame: u32Index of a last frame at which a produced animation should end.
column_major: boolDefines how to interpret the image - is it pack in rows of frames or columns of frames.