ValueBinding

Enum ValueBinding 

pub enum ValueBinding {
    Position,
    Scale,
    Rotation,
    Property {
        name: ImmutableString,
        value_type: ValueType,
    },
}
Value binding tells the animation system to which of the many properties to set track’s value. It has special cases for the most used properties and a generic one for arbitrary properties. Arbitrary properties are set using reflection system, while the special cases handles bindings to standard properties (such as position, scaling, or rotation) for optimization. Reflection is quite slow to be used as the universal property setting mechanism.

Variants



Position

A binding to position of a scene node.



Scale

A binding to scale of a scene node.



Rotation

A binding to rotation of a scene node.



Property

A binding to an arbitrary property of a scene node.

Fields

name: ImmutableString

A path to a property (foo.bar.baz[1].foobar@EnumVariant.stuff)

value_type: ValueType

Actual property type (only numeric properties are supported).

Implementations

Source

impl ValueBinding

pub const PROPERTY_NAME: &'static str = "Property@name"

pub const PROPERTY_VALUE_TYPE: &'static str = "Property@value_type"