BoundValue

Struct BoundValue 

pub struct BoundValue {
    pub binding: ValueBinding,
    pub value: TrackValue,
}
A value that is bound to a property.

Fields

binding: ValueBinding

A property to which the value is bound to.

value: TrackValue

The new value for the property the binding points to.

Implementations

Source

impl BoundValue

pub fn blend_with(&mut self, other: &Self, weight: f32)

Blends the current value with an other value using the given weight. See TrackValue::blend_with for more info.

pub fn apply_to_object( &self, object: &mut dyn Reflect, property_path: &str, value_type: ValueType, )

Sets a property of the given object.