pub enum StateAction<T: EntityId> {
None,
RewindAnimation(Handle<Animation<T>>),
EnableAnimation(Handle<Animation<T>>),
DisableAnimation(Handle<Animation<T>>),
EnableRandomAnimation(Vec<Handle<Animation<T>>>),
}Expand description
An action, that will be executed by a state. It usually used to rewind, enable/disable animations
when entering or leaving states. This is useful in situations when you have a one-shot animation
and you need to rewind it before when entering some state. For example, you may have looped idle
state and one-shot attack state. In this case, you need to use StateAction::RewindAnimation
to tell the engine to automatically rewind the animation before using it. Otherwise, when the
transition will happen, the animation could be ended already and you’ll get “frozen” animation.
Variants
None
No action.
RewindAnimation(Handle<Animation<T>>)
Rewinds the animation.
EnableAnimation(Handle<Animation<T>>)
Enables the animation.
DisableAnimation(Handle<Animation<T>>)
Disables the animation.
EnableRandomAnimation(Vec<Handle<Animation<T>>>)
Enables random animation from the list. It could be useful if you want to add randomization to your state machine. For example, you may have few melee attack animations and all of them are suitable for every situation, in this case you can add randomization to make attacks less predictable.
Implementations
Sourceimpl<T: EntityId> StateAction<T>
impl<T: EntityId> StateAction<T>
pub const REWIND_ANIMATION_F_0: &'static str = "RewindAnimation@0"
pub const ENABLE_ANIMATION_F_0: &'static str = "EnableAnimation@0"
pub const DISABLE_ANIMATION_F_0: &'static str = "DisableAnimation@0"
pub const ENABLE_RANDOM_ANIMATION_F_0: &'static str = "EnableRandomAnimation@0"
Sourceimpl<T: EntityId> StateAction<T>
impl<T: EntityId> StateAction<T>
Sourcepub fn apply(&self, animations: &mut AnimationContainer<T>)
pub fn apply(&self, animations: &mut AnimationContainer<T>)
Applies the action to the given animation container.