pub enum TrackValue {
Real(f32),
Vector2(Vector2<f32>),
Vector3(Vector3<f32>),
Vector4(Vector4<f32>),
UnitQuaternion(UnitQuaternion<f32>),
}Expand description
A real value that can be produced by an animation track. Animations always operate on real numbers (f32) for any kind
of machine numeric types (including bool). This is needed to be able to blend values; final blending result is then
converted to an actual machine type of a target property.
Variants
Real(f32)
A real number.
Vector2(Vector2<f32>)
A 2-dimensional vector of real values.
Vector3(Vector3<f32>)
A 3-dimensional vector of real values.
Vector4(Vector4<f32>)
A 4-dimensional vector of real values.
UnitQuaternion(UnitQuaternion<f32>)
A quaternion that represents some rotation.
Implementations
Sourceimpl TrackValue
impl TrackValue
Sourcepub fn blend_with(&mut self, other: &Self, weight: f32)
pub fn blend_with(&mut self, other: &Self, weight: f32)
Mixes (blends) the current value with an other value using the given weight. Blending is possible only if the types are the same.
Sourcepub fn apply_to_any(&self, any: &mut dyn Any, value_type: ValueType) -> bool
pub fn apply_to_any(&self, any: &mut dyn Any, value_type: ValueType) -> bool
Tries to perform a numeric type casting of the current value to some other and returns a boxed value, that can be used to set the value using reflection.