pub struct BoundValue {
pub binding: ValueBinding,
pub value: TrackValue,
}Expand description
A value that is bound to a property.
Fields
binding: ValueBindingA property to which the value is bound to.
value: TrackValueThe new value for the property the binding points to.
Implementations
Sourceimpl BoundValue
impl BoundValue
Sourcepub fn blend_with(&mut self, other: &Self, weight: f32)
pub fn blend_with(&mut self, other: &Self, weight: f32)
Blends the current value with an other value using the given weight. See TrackValue::blend_with for
more info.
Sourcepub fn apply_to_object(
&self,
object: &mut dyn Reflect,
property_path: &str,
value_type: ValueType,
)
pub fn apply_to_object( &self, object: &mut dyn Reflect, property_path: &str, value_type: ValueType, )
Sets a property of the given object.